==> styletron-server-2.0.1-beta.0.tgz: package/lib/styletron-server.js <==
var cacheToCss = require('./cache-to-css');
var cacheToStylesheets = require('./cache-to-stylesheets');
var generateHtmlString = require('./generate-html-string');
var StyletronCore = require('styletron-core');

/**
 * StyletronServer
 * @packagename styletron-server
 * @extends StyletronCore
 */
var StyletronServer = (function (StyletronCore) {
  function StyletronServer() {
    StyletronCore.call(this);
    this.injectionCallCount = 0;
  }

  if ( StyletronCore ) StyletronServer.__proto__ = StyletronCore;
  StyletronServer.prototype = Object.create( StyletronCore && StyletronCore.prototype );
  StyletronServer.prototype.constructor = StyletronServer;

  StyletronServer.prototype.injectDeclaration = function injectDeclaration (decl) {
    this.injectionCount++;
    return StyletronCore.prototype.injectDeclaration.call(this, decl);
  };

  StyletronServer.prototype.getStylesheets = function getStylesheets () {
    return cacheToStylesheets(this.cache);
  };

  StyletronServer.prototype.getStylesheetsHtml = function getStylesheetsHtml (className) {
    if ( className === void 0 ) className = 'styletron';

    return generateHtmlString(this.getStylesheets(), className);
  };

  /**
   * Get the CSS string of cache
   * @return {String} The string of CSS
   * @example
   * const styletron = new StyletronServer();
   *
   * styletron.injectDeclaration({prop: 'color', val: 'red'});
   * // → 'c0'
   * styletron.getCss();
   * // → '.c0{color:red}'
   */
  StyletronServer.prototype.getCss = function getCss () {
    return cacheToCss(this.cache);
  };

  StyletronServer.prototype.getInjectionCallCount = function getInjectionCallCount () {
    return this.injectionCallCount;
  };

  return StyletronServer;
}(StyletronCore));

module.exports = StyletronServer;

==> styletron-server-2.0.2-beta.0.tgz: package/lib/styletron-server.js <==
var cacheToCss = require('./cache-to-css');
var cacheToStylesheets = require('./cache-to-stylesheets');
var generateHtmlString = require('./generate-html-string');
var StyletronCore = require('styletron-core');

/**
 * StyletronServer
 * @packagename styletron-server
 * @extends StyletronCore
 */
var StyletronServer = (function (StyletronCore) {
  function StyletronServer(opts) {
    StyletronCore.call(this, opts);
  }

  if ( StyletronCore ) StyletronServer.__proto__ = StyletronCore;
  StyletronServer.prototype = Object.create( StyletronCore && StyletronCore.prototype );
  StyletronServer.prototype.constructor = StyletronServer;

  StyletronServer.prototype.injectDeclaration = function injectDeclaration (decl) {
    return StyletronCore.prototype.injectDeclaration.call(this, decl);
  };

  /**
   * Get an array of stylesheet objects
   * @return {Array} Array of stylesheet objects
   * @example
   * const styletron = new StyletronServer();
   *
   * styletron.injectDeclaration({prop: 'color', val: 'red'});
   * // → 'c0'
   * styletron.getStylesheets();
   * // → [{css: '.c0{color:red}'}]
   */
  StyletronServer.prototype.getStylesheets = function getStylesheets () {
    return cacheToStylesheets(this.cache);
  };

  /**
   * Get a string of style elements for server rendering
   * @return {String} The string of HTML
   * @param {String} className=_styletron_hydrate_ Class name for style elements
   * @example
   * const styletron = new StyletronServer();
   * styletron.injectDeclaration({prop: 'color', val: 'red'});
   * // → 'c0'
   * styletron.getStylesheetsHtml();
   * // → '<style class="_styletron_hydrate_">.c0{color:red}</style>'
   * styletron.getStylesheetsHtml('custom_class');
   * // → '<style class="custom_class">.c0{color:red}</style>'
   */
  StyletronServer.prototype.getStylesheetsHtml = function getStylesheetsHtml (className) {
    if ( className === void 0 ) className = '_styletron_hydrate_';

    return generateHtmlString(this.getStylesheets(), className);
  };

  /**
   * Get the CSS string. For hydrating styles on the client,
   * [`getStylesheetsHtml`]{@link StyletronServer#getStylesheetsHtml} or [`getStylesheets`]{@link StyletronServer#getStylesheets} should be used instead. 
   * @return {String} The string of CSS
   * @example
   * const styletron = new StyletronServer();
   *
   * styletron.injectDeclaration({prop: 'color', val: 'red'});
   * // → 'c0'
   * styletron.getCss();
   * // → '.c0{color:red}'
   */
  StyletronServer.prototype.getCss = function getCss () {
    return cacheToCss(this.cache);
  };

  return StyletronServer;
}(StyletronCore));

module.exports = StyletronServer;
